Development
===========
.. _github: http://github.com/alisaifee/holmium.core/
.. _issue tracker: http://github.com/alisaifee/holmium.core/issues
.. _travis: https:/travis-ci.org/#!/alisaifee/holmium.core 
.. _coveralls: https://coveralls.io/r/alisaifee/holmium.core

Contributors
~~~~~~~~~~~~
.. include:: ../../CONTRIBUTORS.rst

Project Resources
~~~~~~~~~~~~~~~~~
Continuous Integration
    The project is being continuously built with `travis`_ against python 2.6 & 2.7. Code coverage details can be viewed at `coveralls`_

Code
    The code is hosted on `github`_.

Bugs, Feature Requests
    Tracked at the `issue tracker`_.

Questions
    Freenode irc server : #holmium
